@@ -22,9 +22,10 @@
 
 #include <config.h>
 #include <string.h>
+#include <unistd.h>
 
 #include <gtk/gtk.h>
-#include <gnome.h>
+#include <libgnome/gnome-config.h>
 #include <glade/glade.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
@@ -36,7 +37,7 @@
 #include "gtk-utils.h"
 
 
-#define GLADE_FILE "file_roller.glade"
+#define GLADE_FILE "file-roller.glade"
 
 
 typedef struct {
@@ -113,7 +114,7 @@ file_sel_response_cb (GtkWidget    *widget,
 		char      *utf8_path;
 		char      *message;
 
-		utf8_path = g_filename_to_utf8 (current_folder, -1, NULL, NULL, NULL);
+		utf8_path = g_filename_display_name (current_folder);
 		message = g_strdup_printf (_("You don't have the right permissions to read files from folder \"%s\""), utf8_path);
 		g_free (utf8_path);
 
@@ -158,13 +159,10 @@ file_sel_response_cb (GtkWidget    *widget,
 		if (utf8_only_spaces (exclude_files))
 			exclude_files = NULL;
 
-		if (strcmp (folder, current_folder) == 0)
-			dest_dir = NULL;
-		else
-			dest_dir = g_build_path (G_DIR_SEPARATOR_S,
-						 window_get_current_location (window),
-						 file_name_from_path (folder),
-						 NULL);
+		dest_dir = g_build_path (G_DIR_SEPARATOR_S,
+					 window_get_current_location (window),
+					 file_name_from_path (folder),
+					 NULL);
 		
 		window_archive_add_with_wildcard (window,
 						  include_files,
@@ -245,7 +243,7 @@ selection_changed_cb (GtkWidget  *file_sel,
                 char      *utf8_path;
                 char      *message;
 		
-                utf8_path = g_filename_to_utf8 (current_folder, -1, NULL, NULL, NULL);
+                utf8_path = g_filename_display_name (current_folder);
                 message = g_strdup_printf (_("You don't have the right permissions to read files from folder \"%s\""), utf8_path);
                 g_free (utf8_path);
 		
@@ -299,7 +297,7 @@ add_folder_cb (GtkWidget *widget,
 	DialogData  *data;
 	gchar       *dir;
 	GtkWidget   *main_box;
-	GtkWidget   *vbox, *hbox;
+	GtkWidget   *vbox;
 	GtkWidget   *table;	
 
 	data = g_new0 (DialogData, 1);
@@ -350,6 +348,10 @@ add_folder_cb (GtkWidget *widget,
 
 	gtk_box_pack_start (GTK_BOX (vbox), data->add_if_newer_checkbutton, 
 			    TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), data->include_subfold_checkbutton,
+			    TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), data->exclude_symlinks,
+			    TRUE, TRUE, 0);
 
 	table = gtk_table_new (2, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
@@ -382,15 +384,6 @@ add_folder_cb (GtkWidget *widget,
 			  GTK_FILL|GTK_EXPAND, 0,
 			  0, 0);
 
-	gtk_box_pack_start (GTK_BOX (vbox), data->include_subfold_checkbutton,
-			    TRUE, TRUE, 0);
-
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), data->exclude_symlinks,
-			    TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox,
-			    TRUE, TRUE, 0);
-
 	/**/
 	
 	vbox = gtk_vbox_new (FALSE, 5);
@@ -550,12 +543,12 @@ aod_apply_cb (GtkWidget *widget,
 
 	/* Sync widgets with options. */
 
-	if (base_dir != NULL)
+	if (base_dir != NULL) 
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (data->dialog), base_dir);
-	/* FIXME
+
 	if (filename != NULL)
-		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (data->dialog), filename);
-	*/
+		gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (data->dialog), filename);
+		
 	if (include_files != NULL)
 		gtk_entry_set_text (GTK_ENTRY (data->include_files_entry), include_files);
 	if (exclude_files != NULL)
